package com.adc.da.bs.industrymap.dao;

import com.adc.da.bs.industrymap.vo.BarVO;
import com.adc.da.bs.industrymap.vo.CoDistributePieVO;
import com.adc.da.bs.industrymap.vo.MapVO;
import com.adc.da.bs.industrymap.vo.PieVO;
import com.adc.da.bs.industrymap.vo.VehicleDetailVO;
import com.adc.da.util.http.PageInfo;
import com.adc.da.util.http.PageParam;
import com.adc.da.util.utils.StringUtils;

import lombok.extern.slf4j.Slf4j;

import org.hibernate.SQLQuery;
import org.hibernate.transform.Transformers;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.persistence.EntityManager;
import javax.persistence.Query;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 产业地图dao
 *
 * @author 韩磊
 * @date 2019/3/21 17:25
 */
@Slf4j
@Component
public class IndustryMapDao {

    private static final String AMOUNT = "AMOUNT";

    private static final String WHERE = " WHERE 1=1 ";

    private static final String TS_ADCBS_PLACE_NAME = " FROM NERDS.TS_ADCBS_PLACE_NAME place ";

    private static final String COMPANY_DEL_FLA = " AND company.DEL_FLAG = '0'";

    private static final String COMPANY_NEW_ENERGY = " AND company.NEW_ENERGY = 1";

    private static final String TS_ADCBS_COMPANY_INFO = " FROM NERDS.TS_ADCBS_COMPANY_INFO company ";

    protected final EntityManager entityManager;

    @Autowired
    public IndustryMapDao(EntityManager entityManager) {
        super();
        this.entityManager = entityManager;
    }

    /**
     * 地图悬浮展示
     * 整车企业分布
     *
     * @return
     * @ahtor 韩磊
     */
    public List<MapVO> queryMapAmount() {
        StringBuilder sql = new StringBuilder();
        sql.append(" SELECT place.SP3 name,NVL(count(company.COMPANY_CODE),0) amount ");
        sql.append(TS_ADCBS_PLACE_NAME);
        sql.append(
            " LEFT JOIN NERDS.TS_ADCBS_COMPANY_INFO company ON company.PROVINCE = place.SP3 AND company.DEL_FLAG = '0' AND place.DEL_FLAG = '0' ");
        sql.append(WHERE);
        sql.append(" AND place.SP3 IS NOT NULL ");
        sql.append(" GROUP BY place.SP3 ");
        sql.append(" UNION ALL ");
        sql.append(" SELECT place.SSX_NAME name,NVL(count(company.COMPANY_CODE),0) amount ");
        sql.append(TS_ADCBS_PLACE_NAME);
        sql.append(
            " LEFT JOIN NERDS.TS_ADCBS_COMPANY_INFO company ON company.CITY = place.SSX_NAME AND company.DEL_FLAG = '0' AND place.DEL_FLAG = '0' ");
        sql.append(WHERE);
        sql.append(" AND place.SSX_NAME like '%市' ");
        sql.append(" GROUP BY place.SSX_NAME ");
        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
        List<Map<String, Object>> list = query.getResultList();
        List<MapVO> mapVOS = new ArrayList<>();
        for (Map<String, Object> resultMap : list) {
            MapVO mapVO = new MapVO();
            mapVO.setName(resultMap.get("NAME").toString());
            mapVO.setAmount(resultMap.get(AMOUNT).toString());
            mapVOS.add(mapVO);
        }
        return mapVOS;
    }

    /**
     * 产品申报情况
     *
     * @param areaName
     * @param ym
     * @return
     * @author 韩磊
     */
    public List<BarVO> queryLatestBatchDeclaration(String areaName, Integer newEnergy, String ym) {
        StringBuilder sql = new StringBuilder();
        sql.append(" WITH maxBatchTable AS (SELECT NVL(MAX(TO_NUMBER(BATCH)), 0) maxBatch ");
        if (null != newEnergy && 1 == newEnergy) {
            sql.append("   FROM NERDS.TS_ADCBS_ENERGY_PRODUCT tempprd ");
            sql.append(
                " LEFT JOIN NERDS.TS_ADCBS_BATCH batch ON tempprd.BATCH = batch.XTZ AND batch.DEL_FLAG = '0' ");

        } else {
            sql.append("  FROM NERDS.TS_ADCBS_AFFICHE_PRODUCT tempprd ");
            sql.append(
                " LEFT JOIN NERDS.TS_ADCBS_BATCH batch ON tempprd.BATCH = batch.AFFICHE_BATCH AND batch.DEL_FLAG = '0' ");
        }
        sql.append("WHERE tempprd.DEL_FLAG = '0' ");
        if (StringUtils.isNotEmpty(ym)) {
            sql.append("AND batch.BATCH_TIME = :ym ");
        }
        sql.append(") ");

        sql.append(" SELECT name, shortName, amount,batch FROM( ");
        sql.append(
            " SELECT company.COMPANY_NAME name,company.SHORT_NAME shortName,NVL(COUNT(product.ID),0) amount,product.BATCH batch ");
        if (null != newEnergy && 1 == newEnergy) {
            sql.append(" FROM NERDS.TS_ADCBS_ENERGY_PRODUCT product ");
        } else {
            sql.append(" FROM NERDS.TS_ADCBS_AFFICHE_PRODUCT product ");
        }
        sql.append(" INNER JOIN maxBatchTable ON maxBatchTable.maxBatch = product.BATCH AND product.DEL_FLAG = '0' ");
        sql.append(
            " LEFT JOIN NERDS.TS_ADCBS_COMPANY_INFO company ON company.COMPANY_CODE = product.COMPANY_CODE AND company.DEL_FLAG = '0' ");
        sql.append(" WHERE 1=1   AND company.COMPANY_CODE IS NOT NULL ");
        if (StringUtils.isNoneBlank(areaName)) {
            sql.append(" AND (company.PROVINCE LIKE CONCAT(:province,'%') OR company.CITY LIKE CONCAT(:city,'%'))  ");
        }
        if (null != newEnergy && 1 == newEnergy) {
            sql.append(" and company.NEW_ENERGY = 1 ");
        }
        sql.append("GROUP BY company.COMPANY_NAME,company.SHORT_NAME, product.BATCH ");
        sql.append("ORDER BY NVL(COUNT(product.ID),0) DESC  ");
        sql.append(") WHERE rownum <= 10  ");
/*        SQLQuery query = entityManager.createNativeQuery(sql.toString())
                                      .unwrap(org.hibernate.SQLQuery.class);
//        query.setResultTransformer(Transformers.aliasToBean(BarVO.class));
        query.setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
*/
        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);

        if (StringUtils.isNoneBlank(ym)) {
            query.setParameter("ym", ym);
        }
        if (StringUtils.isNoneBlank(areaName)) {
            query.setParameter("province", areaName);
            query.setParameter("city", areaName);
        }
        Long timeStamp = System.currentTimeMillis();
        List<Map<String, Object>> list = query.getResultList();
        List<BarVO> barVOS = new ArrayList<>();
        for (Map<String, Object> resultMap : list) {
            BarVO barVO = new BarVO();
            if (null != resultMap.get("NAME")) {
                barVO.setName(resultMap.get("NAME").toString());
            }
            if (null != resultMap.get("SHORTNAME")) {
                barVO.setShortName(resultMap.get("SHORTNAME").toString());
            }
            barVO.setAmount(resultMap.get(AMOUNT).toString());
            barVO.setBatch(resultMap.get("BATCH").toString());
            barVOS.add(barVO);
        }

        return barVOS;
    }

    
    public List<BarVO> queryNewLatestBatchDeclaration(String areaName, Integer newEnergy, String ym) {
        StringBuilder sql = new StringBuilder();
        sql.append(" select * from (  ");
        sql.append(" select QYMC,  ");
        sql.append(" replace(replace(replace(replace(QYMC,'有限公司',''),'有限责任公司',''),'制造',''),'股份','') as qyjc,  ");
        sql.append("  COUNT(1) as num,  ");
        sql.append("  max(pc)as pc  ");
        sql.append("  from  GGCAIN06.CPSB_GS GROUP BY QYMC, replace(replace(replace(replace(QYMC,'有限公司',''),'有限责任公司',''),'制造',''),'股份','') order by COUNT(1) desc  ");        
        sql.append("   ) where rownum <= 10 ");    
        
        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
        List<Map<String, Object>> list = query.getResultList();
        List<BarVO> barVOS = new ArrayList<>();
        for (Map<String, Object> resultMap : list) {
            BarVO barVO = new BarVO();
            if (null != resultMap.get("QYMC")) {
                barVO.setName(resultMap.get("QYMC").toString());
            }
            if (null != resultMap.get("QYJC")) {
                barVO.setShortName(resultMap.get("QYJC").toString());
            }
            barVO.setAmount(resultMap.get("NUM").toString());
            barVO.setBatch(resultMap.get("PC").toString());
            barVOS.add(barVO);
        }

        return barVOS;
    }  
    
    public List<BarVO> queryNewTjmlLatestBatchDeclaration(String areaName, Integer newEnergy, String ym) {
        StringBuilder sql = new StringBuilder();
        
        sql.append(" select * from ( ");
        sql.append(" select QYMC, ");
        sql.append(" replace(replace(replace(replace(QYMC,'有限公司',''),'有限责任公司',''),'制造',''),'股份','') as QYJC,  ");
        sql.append(" COUNT(1)  as NUM , ");
        sql.append("  max(pc) as pc  ");
        sql.append("  from NERDS.ZK_ALL_FAB ");
        sql.append(" where GZKZLB = 'X' and PC in ( select max(TO_NUMBER(PC)) from NERDS.ZK_ALL_FAB ) group by QYMC order by COUNT(1) desc  ");
        sql.append(" )  WHERE ROWNUM <= 10 ");       
        
        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
        List<Map<String, Object>> list = query.getResultList();
        List<BarVO> barVOS = new ArrayList<>();
        for (Map<String, Object> resultMap : list) {
            BarVO barVO = new BarVO();
            if (null != resultMap.get("QYMC")) {
                barVO.setName(resultMap.get("QYMC").toString());
            }
            if (null != resultMap.get("QYJC")) {
                barVO.setShortName(resultMap.get("QYJC").toString());
            }
            barVO.setAmount(resultMap.get("NUM").toString());
            barVO.setBatch(resultMap.get("PC").toString());
            barVOS.add(barVO);
        }

        return barVOS;
    }      
    
    /**
     * 查询areaName是否是省
     *
     * @param areaName
     * @return
     */
    public boolean checkProvinceByAreaName(String areaName) {
        StringBuilder sql = new StringBuilder();
        sql.append(" SELECT NVL(COUNT(place.GBCODE),0) num");
        sql.append(TS_ADCBS_PLACE_NAME);
        sql.append(" WHERE length(place.GBCODE) = 2 ");
        sql.append(" AND SSX_NAME not like '%市' ");
        if (StringUtils.isNoneBlank(areaName)) {
            sql.append(" AND place.SSX_NAME like concat(concat('%',?) ,'%') ");
        }
        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
        if (StringUtils.isNoneBlank(areaName)) {
            query.setParameter(1, areaName);
        }
        List<Map<String, Object>> list = query.getResultList();
        if (0 < Integer.parseInt(list.get(0).get("NUM").toString())) {
            return true;
        }
        return false;
    }

    /**
     * 整车企业分布
     *
     * @param areaName
     * @param provinceFlag
     * @param ym
     * @return
     * @author 韩磊
     */
    public CoDistributePieVO queryVehicleDistribution(String areaName, boolean provinceFlag, Integer newEnergy,
        String ym) {

        StringBuilder sql = new StringBuilder();
        //全国
        if (StringUtils.isEmpty(areaName)) {
//            sql.append(" SELECT to_char(COUNT(DISTINCT company.COMPANY_NAME))  amount ,company.PROVINCE name,company.PROVINCE fullName ");
            sql.append(" SELECT to_char(COUNT(company.COMPANY_NAME))  amount ,company.PROVINCE name,company.PROVINCE fullName ");
            sql.append(TS_ADCBS_COMPANY_INFO);
            sql.append(" WHERE company.DEL_FLAG ='0'");
            if (null != newEnergy && 1 == newEnergy) {
                sql.append(COMPANY_NEW_ENERGY);
            }
            sql.append(" GROUP BY company.PROVINCE ");
            sql.append(" ORDER BY COUNT(DISTINCT company.COMPANY_NAME) DESC ");
        } else if (provinceFlag && StringUtils.isNotEmpty(areaName)) {
            //选择某个省，该省所有市 统计数据
            sql.append(
                " SELECT to_char(COUNT(DISTINCT company.COMPANY_NAME))  amount ,company.CITY name,company.CITY fullName ");
            sql.append(TS_ADCBS_COMPANY_INFO);
            sql.append(WHERE);
            if (null != newEnergy && 1 == newEnergy) {
                sql.append(COMPANY_NEW_ENERGY);
            }
            sql.append(COMPANY_DEL_FLA);
            sql.append(" AND company.PROVINCE like concat(concat('%',:areaName),'%') ");
            sql.append(" GROUP BY company.CITY ");
            sql.append(" ORDER BY COUNT(DISTINCT company.COMPANY_NAME) DESC ");
        } else {
            //选择市 该市 统计数据
            //关联批次时间
            sql.append(" WITH maxBatchTable AS (SELECT NVL(MAX(BATCH), 0) maxBatch ");
            if (null != newEnergy && 1 == newEnergy) {
                sql.append("   FROM NERDS.TS_ADCBS_ENERGY_PRODUCT tempprd ");
                sql.append(
                    " LEFT JOIN NERDS.TS_ADCBS_BATCH batch ON tempprd.BATCH = batch.ENERGY_BATCH AND batch.DEL_FLAG = '0' ");

            } else {
                sql.append("  FROM NERDS.TS_ADCBS_AFFICHE_PRODUCT tempprd ");
                sql.append(
                    " LEFT JOIN NERDS.TS_ADCBS_BATCH batch ON tempprd.BATCH = batch.AFFICHE_BATCH AND batch.DEL_FLAG = '0' ");
            }
            sql.append("WHERE tempprd.DEL_FLAG = '0' ");
            if (StringUtils.isNotEmpty(ym)) {
                sql.append("AND batch.BATCH_TIME = :ym ");
            }
            sql.append(") ");

            sql.append(
                "  SELECT company.COMPANY_NAME fullName,company.SHORT_NAME name,to_char(NVL(COUNT(prd.PRODUCT_CODE),0)) amount ");
            sql.append("FROM NERDS.TS_ADCBS_COMPANY_INFO company");
            sql.append(" LEFT JOIN (SELECT product.COMPANY_CODE,product.PRODUCT_CODE ");
            if (null != newEnergy && 1 == newEnergy) {
                sql.append(" FROM NERDS.TS_ADCBS_ENERGY_PRODUCT product ");
            } else {
                sql.append(" FROM NERDS.TS_ADCBS_AFFICHE_PRODUCT product ");
            }
            sql.append(
                " INNER JOIN maxBatchTable ON maxBatchTable.maxBatch = product.BATCH AND product.DEL_FLAG = '0') prd  ON prd.COMPANY_CODE = company.COMPANY_CODE ");
            sql.append(WHERE);
            sql.append("AND company.DEL_FLAG = '0' ");
            if (StringUtils.isNoneBlank(areaName)) {
                sql.append(" AND (company.CITY LIKE CONCAT(:areaName,'%'))  ");
            }
            if (null != newEnergy && 1 == newEnergy) {
                sql.append(" and company.NEW_ENERGY = 1");
            }
            sql.append("GROUP BY company.COMPANY_NAME,company.SHORT_NAME ");
            sql.append("ORDER BY NVL(COUNT(prd.PRODUCT_CODE),0) DESC  ");
        }
        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);

        if (!provinceFlag && StringUtils.isNotEmpty(areaName) && StringUtils.isNotEmpty(ym)) {
            query.setParameter("ym", ym);
        }
        if (StringUtils.isNoneBlank(areaName)) {
            query.setParameter("areaName", areaName);
        }
        Long timeStamp = System.currentTimeMillis();
        List<Map<String, String>> list = query.getResultList();
        CoDistributePieVO coDistributePieVO = new CoDistributePieVO();
        List<PieVO> pieVOS = new ArrayList<>();
        Integer total = 0;
        for (Map<String, String> resultMap : list) {
            PieVO pieVO = new PieVO();
            pieVO.setFullName(resultMap.get("FULLNAME"));
            pieVO.setName(resultMap.get("NAME"));
            pieVO.setAmount(resultMap.get(AMOUNT));
            total += Integer.parseInt(pieVO.getAmount());
            pieVOS.add(pieVO);
        }
        coDistributePieVO.setTotal(total);
        coDistributePieVO.setPieVOList(pieVOS);

        return coDistributePieVO;
    }

    /**
     * 环状图-详情
     *
     * @param areaName
     * @param provinceFlag
     * @param newEnergy
     * @return
     */
    public List<VehicleDetailVO> queryVehicleDetail(String areaName, boolean provinceFlag, Integer newEnergy,
        PageParam page) {
        StringBuilder sql = new StringBuilder("SELECT ROWNUM COU ,T.* FROM (");
        if (provinceFlag && StringUtils.isNotEmpty(areaName)) {
            //选择某个省，该省所有市 统计数据
            sql.append(
                " SELECT company.COMPANY_CODE code ,company.COMPANY_NAME name,company.PROVINCE province,company.CITY city ");
            sql.append(TS_ADCBS_COMPANY_INFO);
            sql.append(WHERE);
            if (null != newEnergy && 1 == newEnergy) {
                sql.append(COMPANY_NEW_ENERGY);
            }
            sql.append(COMPANY_DEL_FLA);
            sql.append(" AND company.PROVINCE like concat(concat('%',?),'%') ");
        } else {
            //选择市 该市 统计数据
            sql.append(
                " SELECT company.COMPANY_CODE code ,company.COMPANY_NAME name,company.PROVINCE province,company.CITY city ");
            sql.append(TS_ADCBS_COMPANY_INFO);
            sql.append(WHERE);
            sql.append(COMPANY_DEL_FLA);
            if (null != newEnergy && 1 == newEnergy) {
                sql.append(COMPANY_NEW_ENERGY);
            }
            sql.append(" AND company.CITY like concat(concat('%',?),'%') ");
        }
        sql.append(" ) T ");
        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
//        query.setFirstResult((page.getOffset() - 1) * page.getLimit());
        query.setFirstResult(page.getOffset());
        query.setMaxResults(page.getLimit());
        if (StringUtils.isNoneBlank(areaName)) {
            query.setParameter(1, areaName);
        }
        List<Map<String, Object>> list = query.getResultList();
        List<VehicleDetailVO> vehicleDetailVOS = new ArrayList<>();
        for (Map<String, Object> resultMap : list) {
            VehicleDetailVO vehicleDetailVO = new VehicleDetailVO();
            vehicleDetailVO.setCompanyCode(resultMap.get("CODE").toString());
            vehicleDetailVO.setCompanyName(resultMap.get("NAME").toString());
            vehicleDetailVO.setProvince(resultMap.get("PROVINCE").toString());
            vehicleDetailVO.setCity(resultMap.get("CITY").toString());
            vehicleDetailVOS.add(vehicleDetailVO);
        }
        return vehicleDetailVOS;
    }

    public Long countVehicleDetail(String areaName, boolean provinceFlag, Integer newEnergy) {
        StringBuilder sql = new StringBuilder();
        if (provinceFlag && StringUtils.isNotEmpty(areaName)) {
            //选择某个省，该省所有市 统计数据
            sql.append(
                " SELECT COUNT(company.COMPANY_NAME) num ");
            sql.append(TS_ADCBS_COMPANY_INFO);
            sql.append(WHERE);
            if (null != newEnergy && 1 == newEnergy) {
                sql.append(COMPANY_NEW_ENERGY);
            }
            sql.append(COMPANY_DEL_FLA);
            sql.append(" AND company.PROVINCE like concat(concat('%',?),'%') ");
        } else {
            //选择市 该市 统计数据
            sql.append(
                " SELECT COUNT(company.COMPANY_NAME) num ");
            sql.append(TS_ADCBS_COMPANY_INFO);
            sql.append(WHERE);
            sql.append(COMPANY_DEL_FLA);
            if (null != newEnergy && 1 == newEnergy) {
                sql.append(COMPANY_NEW_ENERGY);
            }
            sql.append(" AND company.CITY like concat(concat('%',?),'%') ");
        }
        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
        if (StringUtils.isNoneBlank(areaName)) {
            query.setParameter(1, areaName);
        }
        List<Map<String, Object>> list = query.getResultList();
        return Long.parseLong(list.get(0).get("NUM").toString());
    }

	/**   
	 * @Title: enterpriseRanking   
	 * @Description: TODO(这里用一句话描述这个方法的作用)    
	 * @param @param areaName
	 * @param @param newEnergy
	 * @param @param ym
	 * @param @return    设定文件   
	 * @return PageInfo<VehicleDetailVO>    返回类型   
	 * @author ADC_ZH 
	 * @date 下午1:58:18 
	*/   
	public List<BarVO> enterpriseRanking(String type,String type1,
			String startTime, String endTime) {
        StringBuilder sql = new StringBuilder();
        sql.append(" SELECT * FROM ");
        sql.append(" (SELECT  a.company_code ,t.COMPANY_NAME NAME,t.SHORT_NAME,count(1) AMOUNT FROM( ");
        sql.append(" (SELECT P1.* FROM NERDS.TS_ADCBS_AFFICHE_PRODUCT P1 ");
        sql.append(" LEFT JOIN NERDS.TS_ADCBS_BATCH batch1 ON P1.BATCH = batch1.AFFICHE_BATCH AND BATCH1.DEL_FLAG = '0'  ");
        sql.append(" WHERE 1=1 ");
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	sql.append(" AND P1.SP1= :type");
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	sql.append(" AND P1.SP2= :type1");
        }
        if(StringUtils.isNotEmpty(startTime)){
        	sql.append(" AND batch1.BATCH_TIME>=:startTime ");
        }
        if(StringUtils.isNotEmpty(endTime)){
        	sql.append(" AND batch1.BATCH_TIME<=:endTime ");
        }
//        sql.append(" batch1.BATCH_TIME>='2018-11' AND batch1.BATCH_TIME<='2019-01' ");
        sql.append(" ) ");
        /*2020-07-07修改为只查询新产品*/
       /* sql.append(" UNION ");
        sql.append(" (SELECT P2.* FROM NERDS.TS_ADCBS_ENERGY_PRODUCT P2 ");
        sql.append(" LEFT JOIN NERDS.TS_ADCBS_BATCH batch2 ON P2.BATCH = batch2.XTZ AND BATCH2.DEL_FLAG = '0'  ");
        sql.append(" WHERE 1=1 ");
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	sql.append(" AND P2.SP1= :type");
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	sql.append(" AND P2.SP2= :type1");
        }
        if(StringUtils.isNotEmpty(startTime)){
        	sql.append(" AND batch2.BATCH_TIME>=:startTime ");
        }
        if(StringUtils.isNotEmpty(endTime)){
        	sql.append(" AND batch2.BATCH_TIME<=:endTime ");
        }
//        sql.append(" batch2.BATCH_TIME>='2018-11' AND batch2.BATCH_TIME<='2019-01' ");
        sql.append(" ) ");*/
        sql.append(" )a LEFT JOIN  NERDS.TS_ADCBS_COMPANY_INFO t on a.company_code=t.company_code ");
        sql.append(" where t.SHORT_NAME is NOT NULL   ");
        sql.append(" GROUP BY a.company_code,t.SHORT_NAME,t.COMPANY_NAME ORDER BY count(1) DESC ) ");
        sql.append(" WHERE ROWNUM<11 ");
        SQLQuery query = entityManager.createNativeQuery(sql.toString())
                .unwrap(org.hibernate.SQLQuery.class);
        //query.setResultTransformer(Transformers.aliasToBean(BarVO.class));
        query.setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
        /*if (StringUtils.isNoneBlank(ym)) {
        	query.setParameter("ym", ym);
        }
        if (StringUtils.isNoneBlank(areaName)) {
        	query.setParameter("province", areaName);
        	query.setParameter("city", areaName);
        }*/
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	query.setParameter("type", type);
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	query.setParameter("type1", type1);
        }
        if(StringUtils.isNotEmpty(startTime)){
        	query.setParameter("startTime", startTime);
        }
        if(StringUtils.isNotEmpty(endTime)){
        	query.setParameter("endTime", endTime);
        }
        Long timeStamp = System.currentTimeMillis();
        List<Map<String, Object>> list = query.list();
        List<BarVO> barVOS = new ArrayList<>();
        for (Map<String, Object> resultMap : list) {
        	BarVO barVO = new BarVO();
        	if (null != resultMap.get("NAME")) {
        		barVO.setName(resultMap.get("NAME").toString());
        	} 
        	if (null != resultMap.get("SHORT_NAME")) {
        		barVO.setShortName(resultMap.get("SHORT_NAME").toString());
        	}
        	barVO.setAmount(resultMap.get(AMOUNT).toString()); 
        	barVOS.add(barVO);
        }

        return barVOS;
	}

	/**   
	 * @Title: provinceRanking   
	 * @Description: TODO(这里用一句话描述这个方法的作用)    
	 * @param @param areaName
	 * @param @param newEnergy
	 * @param @param ym
	 * @param @return    设定文件   
	 * @return List<BarVO>    返回类型   
	 * @author ADC_ZH 
	 * @date 下午3:43:50 
	*/   
	public List<BarVO> provinceRanking(String type,String type1,
			String startTime, String endTime) {
		StringBuilder sql = new StringBuilder();
        sql.append(" SELECT * FROM ");
        sql.append(" (SELECT  province ,count(1) AMOUNT FROM( ");
        sql.append(" (SELECT P1.* FROM NERDS.TS_ADCBS_AFFICHE_PRODUCT P1 ");
        sql.append(" LEFT JOIN NERDS.TS_ADCBS_BATCH batch1 ON P1.BATCH = batch1.AFFICHE_BATCH AND BATCH1.DEL_FLAG = '0'  ");
        sql.append(" WHERE 1=1 ");
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	sql.append(" AND P1.SP1= :type");
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	sql.append(" AND P1.SP2= :type1");
        }
        if(StringUtils.isNotEmpty(startTime)){
        	sql.append(" AND batch1.BATCH_TIME>=:startTime ");
        }
        if(StringUtils.isNotEmpty(endTime)){
        	sql.append(" AND batch1.BATCH_TIME<=:endTime ");
        }
        //        sql.append(" WHERE BATCH1.BATCH_TIME IN ('201601') ");
        sql.append(" ) ");
        /*sql.append(" UNION ");
        sql.append(" (SELECT P2.* FROM NERDS.TS_ADCBS_ENERGY_PRODUCT P2 ");
        sql.append(" LEFT JOIN NERDS.TS_ADCBS_BATCH batch2 ON P2.BATCH = batch2.XTZ AND BATCH2.DEL_FLAG = '0'  ");
        sql.append(" WHERE 1=1 ");
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	sql.append(" AND P2.SP1= :type");
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	sql.append(" AND P2.SP2= :type1");
        }
        if(StringUtils.isNotEmpty(startTime)){
        	sql.append(" AND batch2.BATCH_TIME>=:startTime ");
        }
        if(StringUtils.isNotEmpty(endTime)){
        	sql.append(" AND batch2.BATCH_TIME<=:endTime ");
        }
        //        sql.append(" WHERE  BATCH2.BATCH_TIME IN ('201601') ");
        sql.append(" ) ");*/
        sql.append(" )a LEFT JOIN  NERDS.TS_ADCBS_COMPANY_INFO t on a.company_code=t.company_code ");
        sql.append(" where t.province is NOT NULL    ");
        sql.append(" GROUP BY  t.province ORDER BY count(1) DESC ) ");
        sql.append(" WHERE ROWNUM<11 ");
        SQLQuery query = entityManager.createNativeQuery(sql.toString())
                .unwrap(org.hibernate.SQLQuery.class);
        //query.setResultTransformer(Transformers.aliasToBean(BarVO.class));
        query.setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
       /* if (StringUtils.isNoneBlank(ym)) {
        	query.setParameter("ym", ym);
        }
        if (StringUtils.isNoneBlank(areaName)) {
        	query.setParameter("province", areaName);
        	query.setParameter("city", areaName);
        }*/
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	query.setParameter("type", type);
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	query.setParameter("type1", type1);
        }
        if(StringUtils.isNotEmpty(startTime)){
        	query.setParameter("startTime", startTime);
        }
        if(StringUtils.isNotEmpty(endTime)){
        	query.setParameter("endTime", endTime);
        }
        Long timeStamp = System.currentTimeMillis();
        List<Map<String, Object>> list = query.list();
        List<BarVO> barVOS = new ArrayList<>();
        for (Map<String, Object> resultMap : list) {
        	BarVO barVO = new BarVO();
        	if (null != resultMap.get("PROVINCE")) {
        		barVO.setName(resultMap.get("PROVINCE").toString());
        	} 
        	barVO.setAmount(resultMap.get(AMOUNT).toString()); 
        	barVOS.add(barVO);
        }

        return barVOS;
	}

	/**   
	 * @Title: brandRanking   
	 * @Description: TODO(这里用一句话描述这个方法的作用)    
	 * @param @param areaName
	 * @param @param newEnergy
	 * @param @param ym
	 * @param @return    设定文件   
	 * @return List<BarVO>    返回类型   
	 * @author ADC_ZH 
	 * @date 下午4:03:37 
	*/   
	public List<BarVO> brandRanking(String type,String type1,
			String startTime, String endTime) {
		StringBuilder sql = new StringBuilder();
        sql.append(" SELECT ROWNUM RN ,t.* FROM ");
        sql.append(" (SELECT  PRODUCT_BRAND ,count(1) AMOUNT FROM( ");
        sql.append(" (SELECT P1.* FROM NERDS.TS_ADCBS_AFFICHE_PRODUCT P1 ");
        sql.append(" LEFT JOIN NERDS.TS_ADCBS_BATCH batch1 ON P1.BATCH = batch1.AFFICHE_BATCH AND BATCH1.DEL_FLAG = '0'  ");
        sql.append(" WHERE 1=1 ");
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	sql.append(" AND P1.SP1= :type");
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	sql.append(" AND P1.SP2= :type1");
        }
        if(StringUtils.isNotEmpty(startTime)){
        	sql.append(" AND batch1.BATCH_TIME>=:startTime ");
        }
        if(StringUtils.isNotEmpty(endTime)){
        	sql.append(" AND batch1.BATCH_TIME<=:endTime ");
        }
        //        sql.append(" WHERE BATCH1.BATCH_TIME IN ('201601') ");
        sql.append(" ) ");
        /*sql.append(" UNION ");
        sql.append(" (SELECT P2.* FROM NERDS.TS_ADCBS_ENERGY_PRODUCT P2 ");
        sql.append(" LEFT JOIN NERDS.TS_ADCBS_BATCH batch2 ON P2.BATCH = batch2.XTZ AND BATCH2.DEL_FLAG = '0'  ");
        sql.append(" WHERE 1=1 ");
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	sql.append(" AND P2.SP1= :type");
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	sql.append(" AND P2.SP2= :type1");
        }
        if(StringUtils.isNotEmpty(startTime)){
        	sql.append(" AND batch2.BATCH_TIME>=:startTime ");
        }
        if(StringUtils.isNotEmpty(endTime)){
        	sql.append(" AND batch2.BATCH_TIME<=:endTime ");
        }
        //        sql.append(" WHERE  BATCH2.BATCH_TIME IN ('201601') ");
        sql.append(" ) ");*/
        sql.append(" ) ");
        sql.append(" where PRODUCT_BRAND is NOT NULL    ");
        sql.append(" GROUP BY  PRODUCT_BRAND ORDER BY count(1) DESC ) t ");
//        sql.append(" WHERE ROWNUM<11 ");
        SQLQuery query = entityManager.createNativeQuery(sql.toString())
                .unwrap(org.hibernate.SQLQuery.class);
        //query.setResultTransformer(Transformers.aliasToBean(BarVO.class));
        query.setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);
        /*if (StringUtils.isNoneBlank(ym)) {
        	query.setParameter("ym", ym);
        }
        if (StringUtils.isNoneBlank(areaName)) {
        	query.setParameter("province", areaName);
        	query.setParameter("city", areaName);
        }*/
        if(StringUtils.isNotEmpty(type)&& !"全部类别".equals(type)){
        	query.setParameter("type", type);
        }
        if(StringUtils.isNotEmpty(type1)&& !"所有类型".equals(type1)){
        	query.setParameter("type1", type1);
        }
        if(StringUtils.isNotEmpty(startTime)){
        	query.setParameter("startTime", startTime);
        }
        if(StringUtils.isNotEmpty(endTime)){
        	query.setParameter("endTime", endTime);
        }
        Long timeStamp = System.currentTimeMillis();
        List<Map<String, Object>> list = query.list();
        List<BarVO> barVOS = new ArrayList<>();
        for (Map<String, Object> resultMap : list) {
        	BarVO barVO = new BarVO();
        	if (null != resultMap.get("PRODUCT_BRAND")) {
        		barVO.setName(resultMap.get("PRODUCT_BRAND").toString());
        	} 
        	barVO.setAmount(resultMap.get(AMOUNT).toString());
            barVO.setBatch(resultMap.get("RN").toString());

        	barVOS.add(barVO);
        }

        return barVOS;
	}

	/**   
	 * @Title: queryBatch   
	 * @Description: TODO(这里用一句话描述这个方法的作用)    
	 * @param @return    设定文件   
	 * @return Object    返回类型   
	 * @author ADC_ZH 
	 * @date 上午11:32:46 
	*/   
	public Map<String, Object> queryBatch() {
		StringBuilder sql = new StringBuilder();
        sql.append(" SELECT AFFICHE_BATCH,UPDATE_TIME FROM NERDS.TS_ADCBS_BATCH ORDER BY BATCH_TIME||AFFICHE_BATCH DESC ");

        Query query = entityManager.createNativeQuery(sql.toString());
        query.unwrap(org.hibernate.SQLQuery.class).setResultTransformer(Transformers.ALIAS_TO_ENTITY_MAP);

        List<Map<String, Object>> list = query.getResultList();
        Map<String, Object> map=list.get(0);
		return map;
	}
}
