package com.adc.da.bs.industrymap.service;

import com.adc.da.bs.industrymap.dao.IndustryMapDao;
import com.adc.da.bs.industrymap.vo.BarVO;
import com.adc.da.bs.industrymap.vo.CoDistributePieVO;
import com.adc.da.bs.industrymap.vo.MapVO;
import com.adc.da.bs.industrymap.vo.VehicleDetailVO;
import com.adc.da.util.http.PageInfo;
import com.adc.da.util.http.PageParam;
import com.adc.da.util.utils.RedisUtils;
import com.adc.da.util.utils.StringUtils;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * 产业地图service
 *
 * @author 韩磊
 * @date 2019/3/22 8:47
 */
@Service
public class IndustryMapService {
    @Autowired
    private IndustryMapDao industryMapDao;

    @Autowired
    private RedisUtils redisUtils;
    /**
     * 地图悬浮展示
     * 整车企业分布
     *
     * @return
     * @ahtor 韩磊
     */
    public List<MapVO> queryMapAmount() {
        return industryMapDao.queryMapAmount();
    }

    /**
     * 公告产品申报情况
     *
     * @param areaName
     * @param ym
     * @return
     */
    public List<BarVO> queryLatestBatchDeclaration(String areaName, Integer newEnergy, String ym) {
 /*       if(null!=newEnergy &&  newEnergy == 1){
        	//新能源推荐目录新产品申报情况
        	return industryMapDao.queryNewTjmlLatestBatchDeclaration(areaName, newEnergy,ym);	
        }else{
        	//公告新产品申报情况
        	return industryMapDao.queryNewLatestBatchDeclaration(areaName, newEnergy,ym);	
        }*/
        return industryMapDao.queryLatestBatchDeclaration(areaName, newEnergy,ym);
    }

    /**
     * 整车企业分布
     *
     * @param areaName
     * @param ym
     * @return
     */
    public CoDistributePieVO queryVehicleDistribution(String areaName, Integer newEnergy, String ym) {
        boolean provinceFlag = false;
        if (StringUtils.isNotEmpty(areaName)) {
            provinceFlag = industryMapDao.checkProvinceByAreaName(areaName);
        }
        return industryMapDao.queryVehicleDistribution(areaName, provinceFlag, newEnergy,ym);
    }

    /**
     * 环状图-详情
     *
     * @param areaName
     * @param newEnergy
     * @return
     * @author 韩磊
     */
    public PageInfo<VehicleDetailVO> queryVehicleDetail(String areaName, Integer newEnergy, PageParam page) {
        boolean provinceFlag = false;
        PageInfo<VehicleDetailVO> vehicleDetailVOPageInfo = new PageInfo<>();
        Map<String, Object> remap = new HashMap<>();
        if(null == page.getOffset()){
            page.setOffset(1);
        }
        if(null == page.getLimit()){
            page.setLimit(10);
        }
        vehicleDetailVOPageInfo.setPageNo(page.getOffset());
        vehicleDetailVOPageInfo.setPageSize(page.getLimit());
        if (StringUtils.isNotEmpty(areaName)) {
            provinceFlag = industryMapDao.checkProvinceByAreaName(areaName);
        }
        List<VehicleDetailVO> vehicleDetailVOS = industryMapDao
            .queryVehicleDetail(areaName, provinceFlag, newEnergy, page);
        vehicleDetailVOPageInfo.setList(vehicleDetailVOS);
        vehicleDetailVOPageInfo.setCount(industryMapDao.countVehicleDetail(areaName, provinceFlag, newEnergy));
        return vehicleDetailVOPageInfo;
    }

	/**   
	 * @Title: enterpriseRanking   
	 * @Description: TODO(这里用一句话描述这个方法的作用)    
	 * @param @param areaName
	 * @param @param newEnergy
	 * @param @param page
	 * @param @return    设定文件   
	 * @return List<BarVO>  返回类型   
	 * @author ADC_ZH 
	 * @date 下午1:34:37 
	*/   
	public List<BarVO> enterpriseRanking(String type,String type1,
			String startTime, String endTime) {
        return industryMapDao.enterpriseRanking(type, type1, startTime,endTime);

	}

	/**   
	 * @Title: provinceRanking   
	 * @Description: TODO(这里用一句话描述这个方法的作用)    
	 * @param @param areaName
	 * @param @param newEnergy
	 * @param @param ym
	 * @param @return    设定文件   
	 * @return List<BarVO>    返回类型   
	 * @author ADC_ZH 
	 * @date 下午3:43:41 
	*/   
	public List<BarVO> provinceRanking(String type,String type1,
			String startTime, String endTime) {
        return industryMapDao.provinceRanking(type,type1,startTime,endTime);

	}

	/**   
	 * @Title: brandRanking   
	 * @Description: TODO(这里用一句话描述这个方法的作用)    
	 * @param @param areaName
	 * @param @param newEnergy
	 * @param @param ym
	 * @param @return    设定文件   
	 * @return List<BarVO>    返回类型   
	 * @author ADC_ZH 
	 * @date 下午4:03:26 
	*/   
	public List<BarVO> brandRanking(String type,String type1,
	String startTime, String endTime) {
        return industryMapDao.brandRanking(type,type1,startTime,endTime);

	}

	/**   
	 * @Title: queryBatch   
	 * @Description: TODO(这里用一句话描述这个方法的作用)    
	 * @param @return    设定文件   
	 * @return Object    返回类型   
	 * @author ADC_ZH 
	 * @date 上午11:32:23 
	*/   
	public Map<String, Object> queryBatch() { 
        Map<String,Object> res = new HashMap<>();
//        if(redisUtils.exists("queryBatch")){
//            res=(Map<String, Object>) redisUtils.get("queryBatch");
//		}else{
			res = industryMapDao.queryBatch();
			long min=60*24;  
//			redisUtils.set("queryBatch" , res, min, TimeUnit.MINUTES);
//		}
		return res;
	}
}
